@@ -69,7 +69,7 @@ class Simulation:
             name=name,
             started_at=datetime.utcnow(),
             modifiers=modifiers or {},
-
+            options=options
         ))
 
     def current_modifiers(self):
@@ -102,7 +102,7 @@ class Simulation:
         return self._started_at is not None
 
     def running_scenario(self) -> Optional[RunningScenario]:
-        if not self.scenario_is_running():
+        if len(self.scenarios()) == 0:
             return None
 
         return self.scenarios()[-1]
