@@ -13,7 +13,7 @@ class Api(object):
         assert response.status_code == 200, 'Request to start simulation failed, are you sure the host is up? (status code: {})'.format(
             response.status_code)
 
-    def stop_simulation(self, adjust_ms: float):
+    def stop_simulation(self):
         response = requests.post(self.host.url('api/simulation/stop'), json=dict(
             adjust_ms=str(adjust_ms)
         ))
